@@ -69,6 +69,24 @@ sub get {
 				syslog_format   => '[%i] <%d> -- ',
 				syslog_json     => 0,
 			},
+			update => {
+				enable       => 0,
+				no_reload    => 0,
+				no_test      => 0,
+				offline      => 0,
+				fail         => 0,
+				disable_conf => 1,
+				disable_file => undef,
+				enable_conf  => 1,
+				disable_file => undef,
+				modify_conf  => 1,
+				modify_file  => undef,
+				drop_conf    => 1,
+				drop_file    => undef,
+				conf_file    => undef,
+				update_file  => undef,
+				when         => '33 0 * * *',
+			},
 		},
 		suricata_extract => {
 			enable      => 0,
@@ -224,6 +242,7 @@ sub get {
 			syslocation       => '',
 			syscontact        => '',
 			extend_base_dir   => '/usr/local/etc/snmp',
+			config_file       => '/usr/local/etc/snmpd.conf',
 			extend_avail_dir  => '',
 			listen_types      => ['array'],
 			listen_array      => [ 'udp:161', 'tcp:161' ],
@@ -285,6 +304,7 @@ sub get {
 	if ( $^O eq 'linux' ) {
 		$config->{suricata}{config_base}            = '/etc/suricata';
 		$config->{snmp}{extend_base_dir}            = '/etc/snmp/';
+		$config->{snmp}{config_file}            = '/etc/snmp/snmpd.conf';
 		$config->{snmp}{linux_softnet_stat}{enable} = 1;
 
 		#		if ($host_info->{operating_system} eq 'Debian' || $host_info->{operating_system} eq 'Ubuntu') {
@@ -293,6 +313,13 @@ sub get {
 		$config->{suricata}{base_fill_in}{e_defaultruledir} = '/var/lib/suricata/rules';
 	}
 
+	$config->{suricata}{update}{disable_file} = $config->{suricata}{config_base} . '/disable.conf';
+	$config->{suricata}{update}{enable_file}  = $config->{suricata}{config_base} . '/enable.conf';
+	$config->{suricata}{update}{modify_file}  = $config->{suricata}{config_base} . '/modify.conf';
+	$config->{suricata}{update}{drop_file}    = $config->{suricata}{config_base} . '/drop.conf';
+	$config->{suricata}{update}{conf_file}    = $config->{suricata}{config_base} . '/suricata.yaml';
+	$config->{suricata}{update}{update_file}  = $config->{suricata}{config_base} . '/update.yaml';
+
 	return $config;
 } ## end sub get
 
